@@ -55,3 +55,29 @@ pub async fn test_input_box_str() {
         })
     );
 }
+
+#[tokio::test]
+pub async fn test_input_box_slice() {
+    struct Query;
+
+    #[Object]
+    impl Query {
+        async fn box_slice(&self, s: Box<[i32]>) -> Box<[i32]> {
+            s
+        }
+
+        async fn arc_slice(&self, s: Arc<[i32]>) -> Arc<[i32]> {
+            s
+        }
+    }
+
+    let schema = Schema::new(Query, EmptyMutation, EmptySubscription);
+    let query = r#"{ boxSlice(s: [1, 2, 3]) arcSlice(s: [4, 5, 6]) }"#;
+    assert_eq!(
+        schema.execute(query).await.into_result().unwrap().data,
+        value!({
+            "boxSlice": [1, 2, 3],
+            "arcSlice": [4, 5, 6],
+        })
+    );
+}
